﻿//
// Copyright (c) 2011, MindFusion LLC - Bulgaria.
//

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

using MindFusion.Charting.Wpf;
using System.Windows.Media.Effects;

namespace SpecialFeatures
{
    /// <summary>
    /// Interaction logic for Window1.xaml
    /// </summary>
    public partial class Window1 : Window
    {
        SalesList sales;
        SeriesLegend legend;

        public Window1()
        {
            InitializeComponent();

            sales = new SalesList();            

            barChart1.DataSource = sales;
            //barChart1.XLabelPath = "Month";
            barChart1.XAxes[0].Labels = new string[] {"Jan", "Feb", "March", "April" };
            barChart1.XAxes[0].Interval = 1;
            barChart1.XAxes[0].LabelType = LabelType.CustomText;
            barChart1.XAxes[0].CustomLabelPosition = CustomLabelPosition.ChartDataPoints;
            barChart1.XAxes[0].HorLabelAlignment = HorizontalAlignment.Center;
            barChart1.GridType = GridType.Horizontal;
            barChart1.GridFills = new List<Brush>();
            barChart1.GridFills.Add(new SolidColorBrush(Color.FromArgb(120, 199, 199, 199)));
            barChart1.GridFills.Add(new SolidColorBrush(Color.FromArgb(120, 245, 245, 245)));

            barChart1.GridStrokes = new List<Brush>();
            barChart1.GridStrokes.Add(Brushes.Gray);

            barChart1.PlotAreaStrokeThickness = new Thickness(2, 0, 0, 2);

            BarSeries series1 = new BarSeries();
            barChart1.Series.Add(series1);
            series1.XData = new DoubleCollection() { 1, 2, 3, 4 };
            //series1.YData = new DoubleCollection() { 22, 54, 31, 39 };
            //series1.StrokeThickness = 0;
            series1.Effect = new DropShadowEffect() { Opacity = 0.7, ShadowDepth = 3 };
            series1.Fills = new BrushCollection();
            series1.Strokes = new BrushCollection();
            series1.YDataPath = "Profit";
            series1.Fills.Add(Brushes.Yellow);
            series1.Fills.Add(Brushes.SlateGray);
            series1.Fills.Add(Brushes.Orange);
            series1.Fills.Add(Brushes.LightGreen);
            series1.Fills.Add(Brushes.Violet);
            series1.Fills.Add(Brushes.LightSteelBlue);

            legend = new SeriesLegend();
            legend.BorderBrush = new SolidColorBrush(Color.FromArgb(255, 206, 206, 255));
            legend.Background = new SolidColorBrush(Colors.WhiteSmoke);
            legend.BorderThickness = new Thickness(1);
            legend.CornerRadius = new CornerRadius(3);
            legend.LabelsSource = barChart1.XAxes[0].Labels;
            legend.BrushesSource = series1.Fills;
            LayoutPanel.SetDock(legend, Dock.Right);
            legend.VerticalAlignment = VerticalAlignment.Top;
            legend.Margin = new Thickness(10);
            legend.Padding = new Thickness(3);
            barChart1.Legends.Add(legend);

            cbGridType.Items.Add("Horizontal");
            cbGridType.Items.Add("Vertical");
            cbGridType.Items.Add("Cross");
            cbGridType.SelectedIndex = 0;

            cbLegendPosition.Items.Add("Bottom");
            cbLegendPosition.Items.Add("Left");
            cbLegendPosition.Items.Add("Right");
            cbLegendPosition.Items.Add("Top");            
            cbLegendPosition.SelectedIndex = 2;

            cbHorLegendAlignment.Items.Add("Center");
            cbHorLegendAlignment.Items.Add("Left");
            cbHorLegendAlignment.Items.Add("Right");
            cbHorLegendAlignment.SelectedIndex = 1;

            cbVertLegendAlignment.Items.Add("Bottom");
            cbVertLegendAlignment.Items.Add("Center");
            cbVertLegendAlignment.Items.Add("Top");
            cbVertLegendAlignment.SelectedIndex = 2;
        }

        private void cbGridType_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            switch (cbGridType.SelectedIndex)
            {
                case 0:
                    {
                        barChart1.GridType = GridType.Horizontal;
                        break;
                    }
                case 1:
                    {
                        barChart1.GridType = GridType.Vertical;
                        break;
                    }
                case 2:
                    {
                        barChart1.GridType = GridType.Crossed;
                        break;
                    }
            }         
        }

        private void cbHorLegendAlignment_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            switch (cbHorLegendAlignment.SelectedIndex)
            {
                case 0:
                    {
                        legend.HorizontalAlignment = HorizontalAlignment.Center;
                        break;
                    }
                case 1:
                    {
                        legend.HorizontalAlignment = HorizontalAlignment.Left;
                        break;
                    }
                case 2:
                    {
                        legend.HorizontalAlignment = HorizontalAlignment.Right;
                        break;
                    }           
            }                     
        }

        private void cbVertLegendAlignment_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            switch (cbVertLegendAlignment.SelectedIndex)
            {
                case 0:
                    {
                        legend.VerticalAlignment = VerticalAlignment.Bottom;
                        break;
                    }
                case 1:
                    {
                        legend.VerticalAlignment = VerticalAlignment.Center;
                        break;
                    }
                case 2:
                    {
                        legend.VerticalAlignment = VerticalAlignment.Top;
                        break;
                    }
            }
        }

        private void cbLegendPosition_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            switch (cbLegendPosition.SelectedIndex)
            {
                case 0:
                    {
                        LayoutPanel.SetDock(legend, Dock.Bottom);
                        break;
                    }
                case 1:
                    {
                        LayoutPanel.SetDock(legend, Dock.Left);
                        break;
                    }
                case 2:
                    {
                        LayoutPanel.SetDock(legend, Dock.Right);
                        break;
                    }
                case 3:
                    {
                        LayoutPanel.SetDock(legend, Dock.Top);
                        break;
                    }
            }
        }
    }
}
